==> binkd_0.9.2.orig.tar.gz: binkd-0.9.2.orig/Config.h <==
/*
 *  Config.h -- misc defines
 *
 *  Config.h is a part of binkd project
 *
 *  Copyright (C) 1996,1997  Dima Maloff, 5047/13
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version. See COPYING.
 */

/*
 * $Id: Config.h,v 1.6 1997/10/23 04:22:28 mff Exp mff $
 *
 * $Log: Config.h,v $
 * Revision 1.6  1997/10/23  04:22:28  mff
 * Important -- MAX_BLKSIZE is now 0x7FFF (32*1024 was error)
 */

#ifndef _Config_h
#define _Config_h

#ifdef __WATCOMC__
  #include <direct.h>
  #ifndef MAXPATHLEN
    #define MAXPATHLEN NAME_MAX
  #endif
#elif defined (VISUALCPP)
  #include <direct.h>
  #ifndef MAXPATHLEN
    #define MAXPATHLEN _MAX_PATH
  #endif
#else
  #include <sys/param.h>
#endif

/* Please, no spaces here! */
#define PRTCLNAME "binkp"
#define PRTCLVER "1.1"
#define MYNAME "binkd"
#define _MYVER "0.9.2"
#ifdef USE_SOCKS
  #define MYVER _MYVER"/SOCKS"
#else
  #define MYVER _MYVER
#endif

/* Enveronment */
#define MAX_ENV_VAR_NAME 256
#if defined(OS2) || defined(NT) || defined(W95)
  #define PATH_SEPARATOR "\\"
#else
  #define PATH_SEPARATOR "/"
#endif

/* Protocol */
#define DEF_PORT 24554
#define DEF_TIMEOUT (5*60)
#define MIN_BLKSIZE 128
#define MAX_BLKSIZE 0x7fff                  /* Don't change! */
#define DEF_BLKSIZE (4*1024u)
#define MAX_NETNAME 255

/* System... */
#define STACKSIZE (128*1024)
#define MKTMPFILE_TRYES 20

#ifndef O_BINARY
  #define O_BINARY 0
#endif
#if defined(__WATCOMC__) || defined(VISUALCPP)
  #define MKDIR(s) mkdir(s)
#else
  #define MKDIR(s) mkdir(s, 0755)
#endif
#ifndef OS
  #if defined(NT)
    #define OS "NT"
  #elif defined(W95)
    #define OS "Win95"
  #elif defined(OS2)
    #define OS "OS2"
  #endif
#endif

/* Pragmas */
#ifdef __WATCOMC__
  #pragma off (unreferenced);
#endif

#endif

==> binkd_0.9.3.orig.tar.gz: binkd-0.9.3.orig/Config.h <==
/*
 *  Config.h -- misc defines
 *
 *  Config.h is a part of binkd project
 *
 *  Copyright (C) 1996-1998  Dima Maloff, 5047/13
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version. See COPYING.
 */

/*
 * $Id: Config.h,v 1.6 1997/10/23 04:22:28 mff Exp mff $
 *
 * $Log: Config.h,v $
 * Revision 1.6  1997/10/23  04:22:28  mff
 * Important -- MAX_BLKSIZE is now 0x7FFF (32*1024 was error)
 */

#ifndef _Config_h
#define _Config_h

#ifdef __WATCOMC__
  #include <direct.h>
  #ifndef MAXPATHLEN
    #define MAXPATHLEN NAME_MAX
  #endif
#elif defined (VISUALCPP)
  #include <direct.h>
  #ifndef MAXPATHLEN
    #define MAXPATHLEN _MAX_PATH
  #endif
#else
  #include <sys/param.h>
#endif

/* Please, no spaces here! */
#define PRTCLNAME "binkp"
#define PRTCLVER "1.1"
#define MYNAME "binkd"
#define _MYVER "0.9.3g"
#ifdef USE_SOCKS
  #define MYVER _MYVER"/SOCKS"
#else
  #define MYVER _MYVER
#endif

/* Enveronment */
#define MAX_ENV_VAR_NAME 256
#if defined(OS2) || defined(NT) || defined(W95)
  #define PATH_SEPARATOR "\\"
#else
  #define PATH_SEPARATOR "/"
#endif

/* Protocol */
#define DEF_PORT 24554
#define DEF_TIMEOUT (5*60)
#define MIN_BLKSIZE 128
#define MAX_BLKSIZE 0x7fff                  /* Don't change! */
#define DEF_BLKSIZE (4*1024u)
#define MAX_NETNAME 255

/* System... */
#define STACKSIZE (128*1024)
#define MKTMPFILE_TRYES 20

#ifndef O_BINARY
  #define O_BINARY 0
#endif
#if defined(__WATCOMC__) || defined(VISUALCPP)
  #define MKDIR(s) mkdir(s)
#else
  #define MKDIR(s) mkdir(s, 0755)
#endif
#ifndef OS
  #if defined(NT)
    #define OS "NT"
  #elif defined(W95)
    #define OS "Win95"
  #elif defined(OS2)
    #define OS "OS2"
  #endif
#endif

/* Pragmas */
#ifdef __WATCOMC__
  #pragma off (unreferenced);
#endif

#endif
